==> owncloud-10.2.0.zip: owncloud/apps/federatedfilesharing/l10n/ru.js <==
OC.L10N.register(
    "federatedfilesharing",
    {
    "Federated sharing" : "Общий доступ из объединенного общего хранилища",
    "Invalid Federated Cloud ID" : "Неверный ID в объединении облачных хранилищ.",
    "Sharing %s failed, because this item is already shared with %s" : "Не удалось поделиться %s, пользователь %s уже имеет доступ к этому элементу",
    "Not allowed to create a federated share with the same user" : "Не допускается создание федеративного общего ресурса с тем же пользователем",
    "File is already shared with %s" : "Доступ к файлу уже предоставлен %s",
    "Sharing %s failed, could not find %s, maybe the server is currently unreachable." : "Не удалось поделиться %s, не удалось найти %s, возможно, сервер не доступен.",
    "You received \"/%3$s\" as a remote share from %1$s (on behalf of %2$s)" : "Вы получили \"/%3$s\"  в качестве удалённого ресурса из %1$s (от имени %2$s)",
    "You received \"/%3$s\" as a remote share from %1$s" : "Вы получили \"/%3$s\" в качестве удалённого ресурса из %1$s",
    "Accept" : "Принять",
    "Decline" : "Отклонить",
    "Share with me through my #ownCloud Federated Cloud ID, see %s" : "Поделитесь со мной через мой #ownCloud ID в объединении облачных хранилищ, смотрите %s",
    "Share with me through my #ownCloud Federated Cloud ID" : "Поделитесь со мной через мой #ownCloud ID в объединении облачных хранилищ",
    "Federated Cloud Sharing" : "Объединение облачных хранилищ",
    "Open documentation" : "Открыть документацию",
    "Allow users on this server to send shares to other servers" : "Разрешить пользователям делиться с пользователями других серверов",
    "Allow users on this server to receive shares from other servers" : "Разрешить пользователям использовать общие ресурсы с других серверов",
    "Federated Cloud" : "Объединение облачных хранилищ",
    "Your Federated Cloud ID:" : "Ваш ID в объединении облачных хранилищ:",
    "Share it:" : "Поделись этим:",
    "Add to your website" : "Добавить к себе на сайт",
    "Share with me via ownCloud" : "Поделитесь со мной через ownCloud",
    "HTML Code:" : "HTML код:",
    "Add to your ownCloud" : "Добавить в свой ownCloud",
    "Automatically accept remote shares from trusted servers" : "Автоматически принимать удалённый доступ от доверенных серверов"
},
"nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");

==> owncloud-10.4.0.zip: owncloud/apps/federatedfilesharing/l10n/ru.js <==
OC.L10N.register(
    "federatedfilesharing",
    {
    "Federated sharing" : "Общий доступ из объединенного общего хранилища",
    "Add to your ownCloud" : "Добавить в свой ownCloud",
    "Invalid Federated Cloud ID" : "Неверный ID в объединении облачных хранилищ.",
    "Sharing %s failed, because this item is already shared with %s" : "Не удалось поделиться %s, пользователь %s уже имеет доступ к этому элементу",
    "Not allowed to create a federated share with the same user" : "Не допускается создание федеративного общего ресурса с тем же пользователем",
    "File is already shared with %s" : "Доступ к файлу уже предоставлен %s",
    "Sharing %s failed, could not find %s, maybe the server is currently unreachable." : "Не удалось поделиться %s, не удалось найти %s, возможно, сервер не доступен.",
    "Federated Sharing failed: %s" : "Предоставление доступа в объединении не удалось: %s",
    "\"%1$s\" shared \"%3$s\" with you (on behalf of \"%2$s\")" : "Пользователь «%1$s» предоставил вам доступ к «%3$s» (от имени «%2$s»)",
    "\"%1$s\" shared \"%3$s\" with you" : "Пользователь «%1$s» предоставил вам доступ к «%3$s»",
    "\"%1$s\" invited you to view \"%3$s\" (on behalf of \"%2$s\")" : "Пользователь «%1$s» предлагает вам посмотреть «%3$s» (от имени «%2$s»)",
    "\"%1$s\" invited you to view \"%3$s\"" : "Пользователь «%1$s» предлагает вам посмотреть «%3$s»",
    "Accept" : "Принять",
    "Decline" : "Отклонить",
    "Share with me through my #ownCloud Federated Cloud ID, see %s" : "Поделитесь со мной через мой #ownCloud ID в объединении облачных хранилищ, смотрите %s",
    "Share with me through my #ownCloud Federated Cloud ID" : "Поделитесь со мной через мой #ownCloud ID в объединении облачных хранилищ",
    "Federated Cloud Sharing" : "Объединение облачных хранилищ",
    "Open documentation" : "Открыть документацию",
    "Allow users on this server to send shares to other servers" : "Разрешить пользователям делиться с пользователями других серверов",
    "Allow users on this server to receive shares from other servers" : "Разрешить пользователям использовать общие ресурсы с других серверов",
    "Automatically accept remote shares from trusted servers" : "Автоматически принимать удалённый доступ от доверенных серверов",
    "Federated Cloud" : "Объединение облачных хранилищ",
    "Your Federated Cloud ID:" : "Ваш ID в объединении облачных хранилищ:",
    "Share it:" : "Поделись этим:",
    "Add to your website" : "Добавить к себе на сайт",
    "Share with me via ownCloud" : "Поделитесь со мной через ownCloud",
    "HTML Code:" : "HTML код:",
    "Nothing to configure." : "Здесь настраивать нечего."
},
"nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
